{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.5";
      system = "x86_64-linux";
    }
    { out = "/nix/store/i5vf726ifpn9rqh6sbwakwr5ffbn7x9i-cachix-1.7.5-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.5";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/ll6aim1arqachf1zfazmak0f9lqw6lxz-cachix-1.7.5-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.5";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/n4vmc4wzz2b4falkdz0xk1f0zz0cqxjj-cachix-1.7.5-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.5";
      system = "aarch64-linux";
    }
    { out = "/nix/store/hr0p802xvgzn5sbjm4lvmdixilz546vx-cachix-1.7.5-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/d4f247e89f6e10120f911e2e2d2254a050d0f732") { inherit system; }
