{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.7";
      system = "x86_64-linux";
    }
    { out = "/nix/store/y9j15gngm0zwkgd2k2j9xjhixj0wlikl-cachix-1.7.7-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.7";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/nxr2id2jpbbblr42r5hdcdcwgrqrkn06-cachix-1.7.7-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.7";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/93xnyrkxgaid4ign5s4g9d0x4z5ldhhp-cachix-1.7.7-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.7";
      system = "aarch64-linux";
    }
    { out = "/nix/store/v5522kgx343rlz3n458clbccmvg4ma4s-cachix-1.7.7-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/a480f04a65af2deeef661dedd8fc70f0791f44b0") { inherit system; }
