{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.8";
      system = "x86_64-linux";
    }
    { out = "/nix/store/8czki9w34651wm7b9z2k56ar9vlj774z-cachix-1.7.8-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.8";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/67m1rp1wfgviljgd4a15cz478sz42x98-cachix-1.7.8-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.8";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/zgl2iwvkg3bqc56abq34v6q76f6f1z32-cachix-1.7.8-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.8";
      system = "aarch64-linux";
    }
    { out = "/nix/store/0jia144i7bjr4mkfv4d2wnbhzahw7ni0-cachix-1.7.8-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/6b1c028bce9c89e9824cde040d6986d428296055") { inherit system; }
