{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.4";
      system = "x86_64-linux";
    }
    { out = "/nix/store/acfsgbmlm31ijimwrd5g96sgh59lmlc7-cachix-1.7.4-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.4";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/hhhrm1rk9b4l6whiqpvgpmqf494nray5-cachix-1.7.4-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.4";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/yfwziwccd0jiqbkp43pkryhli1xnlb8j-cachix-1.7.4-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.4";
      system = "aarch64-linux";
    }
    { out = "/nix/store/glbz4zdmfj3fxklzm4fr8n2ih9ym2z5d-cachix-1.7.4-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/ac82a513e55582291805d6f09d35b6d8b60637a1") { inherit system; }
