{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.9";
      system = "x86_64-linux";
    }
    { out = "/nix/store/04s6rz3jdn0ky45vbfxhrmdv567xl5rc-cachix-1.7.9-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.9";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/5yg17w4xhx0ryzs8b39sasdhd1sjcl8k-cachix-1.7.9-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.9";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/g4q65cpawibj8h30ikmg2qals2y0x7iw-cachix-1.7.9-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7.9";
      system = "aarch64-linux";
    }
    { out = "/nix/store/hikfb2is50r6m5psr3gacnw3cvv9nirq-cachix-1.7.9-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/8207ad0d501dd3590e0e81a7c56b386a5c4342c9") { inherit system; }
