{ system ? builtins.currentSystem
, onlyFromSource ? false
}:

let
  mkFakeDerivation = attrs: outputs:
    let
        outputNames = builtins.attrNames outputs;
        common = attrs // outputsSet //
            { type = "derivation";
              outputs = outputNames;
            };
        outputToAttrListElement = outputName:
            { name = outputName;
              value = common // {
                inherit outputName;
                outPath = builtins.storePath (builtins.getAttr outputName outputs);
                # TODO: we lie here so that Nix won't build it
                drvPath = builtins.storePath (builtins.getAttr outputName outputs);
              };
            };
        outputsList = map outputToAttrListElement outputNames;
        outputsSet = builtins.listToAttrs outputsList;
    in outputsSet;
  packages = {
    x86_64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7";
      system = "x86_64-linux";
    }
    { out = "/nix/store/gw5pl0by3lqcznmgf4fykhbkz3x5shrl-cachix-1.7-bin";
    }).out;

  x86_64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7";
      system = "x86_64-darwin";
    }
    { out = "/nix/store/q6qm2rw4bqb6rlr4db6kraf4ifabripq-cachix-1.7-bin";
    }).out;

  aarch64-darwin.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7";
      system = "aarch64-darwin";
    }
    { out = "/nix/store/k544ixcx31f3g8mzrrficlxxm77yl3yx-cachix-1.7-bin";
    }).out;

  aarch64-linux.cachix =
  (mkFakeDerivation
    { name = "cachix-1.7";
      system = "aarch64-linux";
    }
    { out = "/nix/store/p1lwv5rr8bli2vk3pwb4mm07qllhw6mv-cachix-1.7-bin";
    }).out;

  };
in if builtins.hasAttr system packages && (!onlyFromSource)
   then packages.${system}
   else import (fetchTarball "https://github.com/NixOS/nixpkgs/tarball/eabe8d3eface69f5bb16c18f8662a702f50c20d5") { inherit system; }
